spannertools.SlurSpanner
========================

.. inheritance-diagram:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner
   :private-bases:

.. autoclass:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.components

    Inherited from :py:class:`spannertools.Spanner <abjad.tools.spannertools.Spanner.Spanner.Spanner>`

.. autoattribute:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.duration_in_seconds

    Inherited from :py:class:`spannertools.Spanner <abjad.tools.spannertools.Spanner.Spanner.Spanner>`

.. autoattribute:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.leaves

    Inherited from :py:class:`spannertools.Spanner <abjad.tools.spannertools.Spanner.Spanner.Spanner>`

.. autoattribute:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.override

    Inherited from :py:class:`spannertools.Spanner <abjad.tools.spannertools.Spanner.Spanner.Spanner>`

.. autoattribute:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.preprolated_duration

    Inherited from :py:class:`spannertools.Spanner <abjad.tools.spannertools.Spanner.Spanner.Spanner>`

.. autoattribute:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.prolated_duration

    Inherited from :py:class:`spannertools.Spanner <abjad.tools.spannertools.Spanner.Spanner.Spanner>`

.. autoattribute:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.set

    Inherited from :py:class:`spannertools.Spanner <abjad.tools.spannertools.Spanner.Spanner.Spanner>`

.. autoattribute:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.start_offset

    Inherited from :py:class:`spannertools.Spanner <abjad.tools.spannertools.Spanner.Spanner.Spanner>`

.. autoattribute:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.stop_offset

    Inherited from :py:class:`spannertools.Spanner <abjad.tools.spannertools.Spanner.Spanner.Spanner>`

.. autoattribute:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. autoattribute:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.written_duration

    Inherited from :py:class:`spannertools.Spanner <abjad.tools.spannertools.Spanner.Spanner.Spanner>`

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.direction

    Inherited from :py:class:`spannertools.DirectedSpanner <abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner>`

Methods
-------

.. automethod:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.append

    Inherited from :py:class:`spannertools.Spanner <abjad.tools.spannertools.Spanner.Spanner.Spanner>`

.. automethod:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.append_left

    Inherited from :py:class:`spannertools.Spanner <abjad.tools.spannertools.Spanner.Spanner.Spanner>`

.. automethod:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.clear

    Inherited from :py:class:`spannertools.Spanner <abjad.tools.spannertools.Spanner.Spanner.Spanner>`

.. automethod:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.extend

    Inherited from :py:class:`spannertools.Spanner <abjad.tools.spannertools.Spanner.Spanner.Spanner>`

.. automethod:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.extend_left

    Inherited from :py:class:`spannertools.Spanner <abjad.tools.spannertools.Spanner.Spanner.Spanner>`

.. automethod:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.fracture

    Inherited from :py:class:`spannertools.Spanner <abjad.tools.spannertools.Spanner.Spanner.Spanner>`

.. automethod:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.fuse

    Inherited from :py:class:`spannertools.Spanner <abjad.tools.spannertools.Spanner.Spanner.Spanner>`

.. automethod:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.index

    Inherited from :py:class:`spannertools.Spanner <abjad.tools.spannertools.Spanner.Spanner.Spanner>`

.. automethod:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.pop

    Inherited from :py:class:`spannertools.Spanner <abjad.tools.spannertools.Spanner.Spanner.Spanner>`

.. automethod:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.pop_left

    Inherited from :py:class:`spannertools.Spanner <abjad.tools.spannertools.Spanner.Spanner.Spanner>`

Special Methods
---------------

.. automethod:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.__call__

    Inherited from :py:class:`spannertools.Spanner <abjad.tools.spannertools.Spanner.Spanner.Spanner>`

.. automethod:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.__contains__

    Inherited from :py:class:`spannertools.Spanner <abjad.tools.spannertools.Spanner.Spanner.Spanner>`

.. automethod:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.__eq__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.__ge__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.__getitem__

    Inherited from :py:class:`spannertools.Spanner <abjad.tools.spannertools.Spanner.Spanner.Spanner>`

.. automethod:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.__gt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.__le__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.__len__

    Inherited from :py:class:`spannertools.Spanner <abjad.tools.spannertools.Spanner.Spanner.Spanner>`

.. automethod:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.__lt__

    Inherited from :py:class:`spannertools.Spanner <abjad.tools.spannertools.Spanner.Spanner.Spanner>`

.. automethod:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.__ne__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.__repr__

    Inherited from :py:class:`spannertools.Spanner <abjad.tools.spannertools.Spanner.Spanner.Spanner>`
